%%%%%% Weights Truncation.
%%%%%% It requires:
%%%%%%      - the array of weights to be changed (W)
%%%%%%      - the number of bits to be either truncated or rounded (bits)
%%%%%%      - the number of decimals available in the net weights
%%%%%%        (net_decimals). Usually this value is 7 (single precision)
%%%%%%      - the type of change ('truncation', 'rounding')
%%%%%% 
%%%%%% Observation: the truncation, achieved through a floor operation,
%%%%%% takes into account the case in which the weight's sign is negative.
function weights = changeWeights(W,bits,net_decimals,type)
        
        %%% Check the validity of the type parameter.
        if not(or(strcmp(type,'rounding'),strcmp(type,'truncation')))
            error('The type is either rounding or truncation');
        end
        
        
        if strcmp(type,'truncation')
            %%% Truncation
            weights = sign(W) .* ...
                floor(abs(W*10^(net_decimals-bits))) ./ ... 
                10^(net_decimals-bits);
        else
            %%% Rounding    
            weights = sign(W) .* ...
                round(abs(W*10^(net_decimals-bits))) ./ ... 
                10^(net_decimals-bits);
        end
end