function [names, memory, computation, inputImageSize] = ...
                                    cnnInspection (cnn, byte_per_parameter)
    layers = cnn.Layers;
    names = string(size(layers));
    memory = Inf(size(layers));
    computation = Inf(size(layers));
    
    % Find out the initial image dimension
    imageSize = layers(1).InputSize(1);
    % Save it as output
    inputImageSize = imageSize;
    
    current_memory = 0;
    current_computation = 0;
    for i=1:size(layers,1)
       names(i) =  layers(i).Name;
       l = cnn.Layers(i);
       % Computation checks
       if contains(names(i),'fc','IgnoreCase',true)
            current_computation = current_computation + ...
               numel(l.Weights) + numel(l.Bias);
       end
       if contains(names(i),'conv','IgnoreCase',true)
          % Update the image size (the Padding is supposed simmetric)
          imageSize = 1 + floor((imageSize - l.FilterSize(1) + 2*l.PaddingSize(1))/l.Stride(1));
          % The third dimension of the filters is the depth resulting from
          % the previous layer
          n_prev = size(l.Weights,3);
          % The fourth dimension is the number of the filters
          n = size(l.Weights,4);
          % Filter size
          filter_size = l.FilterSize(1);
          % The size of the output feature map is the image_size.
          current_computation = current_computation + ...
              n_prev * filter_size^2 * n * imageSize^2;
          
       end
       if contains(names(i),'pool','IgnoreCase',true)
           % Update the image size (the Padding is supposed simmetric)
           imageSize = 1 + floor((imageSize - l.PoolSize(1)+ 2*l.PaddingSize(1))/l.Stride(1));
       end
       
       % Memory checks
       if contains(names(i),["conv","fc"],'IgnoreCase',true)
           current_memory = current_memory + ... 
               byte_per_parameter * numel(l.Weights) + ...
               byte_per_parameter * numel(l.Bias);
       end
       
       
       memory(i) = current_memory;
       computation(i) = current_computation;
    end
    names = names';
end